##QuAM

Quantum Abstract Machine (QuAM) is an abstraction layer. 

It helps users in describing the experiment by wrapping together experimental parameters and an object model 
for building the setup configuration. This ConfigBuilder is an object model over the configuration needed to run 
QUA programs on the QM Quantum Orchestration Platform. 

